@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -98,16 +98,43 @@ class UWC_Data {
   }
 
   function update_content($path,$lang,$title,$author,$text,$status,$order) {
-    $path=$this->prefix.$path;
-    $query=sprintf($this->sql->query["update_content"],
-		   uwc_format_escape_sql($title),
-		   uwc_format_escape_sql($author),
-		   uwc_format_escape_sql(uwc_format_fix_content_text($text)),
-		   (int) uwc_format_escape_sql($status),
-		   (int) uwc_format_escape_sql($order),
-		   uwc_format_escape_sql($path),
-		   uwc_format_escape_sql($lang));
-    $this->query($query);    
+    /* 
+     * Do not perform update if title is NULL/empty, this should
+     * prevent weird bugs (root page being resetted...) and anyway, if one
+     * wants to get rid of content -> delete is safer...
+     */
+    if ($title) {
+      $path=$this->prefix.$path;
+      $query=sprintf($this->sql->query["update_content"],
+		     uwc_format_escape_sql($title),
+		     uwc_format_escape_sql($author),
+		     uwc_format_escape_sql(uwc_format_fix_content_text($text)),
+		     (int) uwc_format_escape_sql($status),
+		     (int) uwc_format_escape_sql($order),
+		     uwc_format_escape_sql($path),
+		     uwc_format_escape_sql($lang));
+      $this->query($query);    
+    }
+  }
+
+  function update_content_without_date_update($path,$lang,$title,$author,$text,$status,$order) {
+    /* 
+     * Do not perform update if title is  NULL/empty, this should
+     * prevent weird bugs (root page being resetted...) and anyway, if one
+     * wants to get rid of content -> delete is safer...
+     */
+    if ($title) {
+      $path=$this->prefix.$path;
+      $query=sprintf($this->sql->query["update_content_without_date_update"],
+		     uwc_format_escape_sql($title),
+		     uwc_format_escape_sql($author),
+		     uwc_format_escape_sql(uwc_format_fix_content_text($text)),
+		     (int) uwc_format_escape_sql($status),
+		     (int) uwc_format_escape_sql($order),
+		     uwc_format_escape_sql($path),
+		     uwc_format_escape_sql($lang));
+      $this->query($query);    
+    }
   }
 
   function delete_content_by_path_and_lang($path,$lang) {
@@ -414,12 +441,19 @@ class UWC_Data {
   }
 
   function update_legend($id,$lang,$alt,$longdesc) {
-    $query=sprintf($this->sql->query["update_legend"],
-		   uwc_format_escape_sql($alt),
-		   uwc_format_escape_sql($longdesc),
-		   (int) uwc_format_escape_sql($id),
-		   uwc_format_escape_sql($lang));
-    $this->query($query);        
+    /* 
+     * Do not perform update if alt (title) is NULL/empty, this should
+     * prevent weird bugs (root page being resetted...) and anyway, if one
+     * wants to get rid of content -> delete is safer...
+     */
+    if ($alt) {
+      $query=sprintf($this->sql->query["update_legend"],
+		     uwc_format_escape_sql($alt),
+		     uwc_format_escape_sql($longdesc),
+		     (int) uwc_format_escape_sql($id),
+		     uwc_format_escape_sql($lang));
+      $this->query($query);
+    }
   }
 
   function delete_image_by_id($id) {
