@@ -1,7 +1,7 @@
 <?php
 /*
  UWiKiCMS is a lightweight web content management system.
- Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>
+ Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
@@ -433,6 +433,14 @@ class UWC_Page {
     if ($home["title"]) {
       $home=uwc_format_text_to_html($home["title"]);
     } else {
+      /*
+       * When being on home page, parent data is unset,
+       * so we just get our current value. Fixes #20032.
+       */
+      $home=$this->get_title();
+    }
+
+    if (! $home) {
       $home=$this->translate("no_title");
     }
 
@@ -1126,13 +1134,23 @@ class UWC_Page {
 	$this->data->move_content($oldpath,$this->get_path());
 	$this->data->move_image($oldpath,$this->get_path());
       }
-      $this->data->update_content($this->get_path(),
-				  $this->get_lang(),
-				  $this->request->get_value("title"),
-				  $this->get_user_id(),
-				  $this->request->get_value("text"),
-				  $this->request->get_value("status"),
-				  $this->request->get_value("order"));
+      if ($this->request->get_value("do_date_update")) {
+	$this->data->update_content($this->get_path(),
+				    $this->get_lang(),
+				    $this->request->get_value("title"),
+				    $this->get_user_id(),
+				    $this->request->get_value("text"),
+				    $this->request->get_value("status"),
+				    $this->request->get_value("order"));
+      } else {
+	$this->data->update_content_without_date_update($this->get_path(),
+							$this->get_lang(),
+							$this->request->get_value("title"),
+							$this->get_user_id(),
+							$this->request->get_value("text"),
+							$this->request->get_value("status"),
+							$this->request->get_value("order"));
+      }
       $this->content->force_update_data();
       break;
     case "delete":
